@@ -14,7 +14,7 @@ with (
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-08-24'; # DATE
 our $DIST = 'Dist-Zilla-Plugin-CopyrightYearFromGit'; # DIST
-our $VERSION = '0.008'; # VERSION
+our $VERSION = '0.009'; # VERSION
 
 has min_year           => (is => 'rw');
 has release_tag_regex  => (is => 'rw');
@@ -100,7 +100,7 @@ Dist::Zilla::Plugin::CopyrightYearFromGit - Set copyright year from git
 
 =head1 VERSION
 
-This document describes version 0.008 of Dist::Zilla::Plugin::CopyrightYearFromGit (from Perl distribution Dist-Zilla-Plugin-CopyrightYearFromGit), released on 2021-08-24.
+This document describes version 0.009 of Dist::Zilla::Plugin::CopyrightYearFromGit (from Perl distribution Dist-Zilla-Plugin-CopyrightYearFromGit), released on 2021-08-24.
 
 =head1 SYNOPSIS
 
@@ -114,7 +114,7 @@ In F<dist.ini>:
  [CopyrightYearFromGit]
  ; release_tag_regex = ^v    ; optional, default is ^(version|ver|v)\d
  ; author_name_regex = foo   ; optional, default is none (any author name will be included)
- ; author_email_regex = foo  ; optional, default is none (any author name will be included)
+ ; author_email_regex = foo  ; optional, default is none (any author email will be included)
 
  ; min_year = 2017           ; optional, setting this would make copyright_year become: 2021, 2019, 2017.
 
@@ -124,7 +124,7 @@ In F<dist.ini>:
  ; exclude_year = 2016
  ; exclude_year = 2017       ; optional, setting this two lines would make copyright_year become: 2021, 2019
 
- ; continuous_year = 1       ; optional, setting this two lines would make copyright_year become: 2021, 2020, 2019, 2018, 2017, 2016
+ ; continuous_year = 1       ; optional, setting this would make copyright_year become: 2021, 2020, 2019, 2018, 2017, 2016
 
 =head1 DESCRIPTION
 
